@@ -8,8 +8,9 @@
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **	Copyright (c) 2008 Gerald Young
-**  Copyright (c) 2008, 2010, 2011 Carlos López
+**	Copyright (c) 2008, 2010-2013 Carlos López
 **	Copyright (c) 2009, 2011 Nikita Kitaev
+**	Copyright (c) 2012 Konstantin Dmitriev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -120,8 +121,6 @@
 #include "modules/module.h"
 #include "modules/mod_palette/mod_palette.h"
 
-#include <sys/stat.h>
-
 #include "ipc.h"
 
 #include "statemanager.h"
@@ -147,16 +146,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#ifndef SYNFIG_USER_APP_DIR
-#ifdef __APPLE__
-#define SYNFIG_USER_APP_DIR	"Library/Synfig"
-#elif defined(_WIN32)
-#define SYNFIG_USER_APP_DIR	"Synfig"
-#else
-#define SYNFIG_USER_APP_DIR	".synfig"
-#endif
-#endif
-
 #ifndef DPM2DPI
 #define DPM2DPI(x)	(float(x)/39.3700787402f)
 #define DPI2DPM(x)	(float(x)*39.3700787402f)
@@ -177,6 +166,17 @@ using namespace studio;
 #	define IMAGE_EXT	"tif"
 #endif
 
+#ifdef WIN32
+#	ifdef PLUGIN_DIR
+#		undef PLUGIN_DIR
+#		define PLUGIN_DIR "share\\synfig\\plugins"
+#	endif
+#endif
+
+#ifndef PLUGIN_DIR
+#	define PLUGIN_DIR "/usr/local/share/synfig/plugins"
+#endif
+
 #include <synfigapp/main.h>
 
 /* === S I G N A L S ======================================================= */
@@ -285,12 +285,15 @@ int studio::App::preferred_y_size=270;
 String studio::App::predefined_size(DEFAULT_PREDEFINED_SIZE);
 String studio::App::predefined_fps(DEFAULT_PREDEFINED_FPS);
 float studio::App::preferred_fps=24.0;
+synfigapp::PluginManager studio::App::plugin_manager;
 #ifdef USE_OPEN_FOR_URLS
 String studio::App::browser_command("open"); // MacOS only
 #else
 String studio::App::browser_command("xdg-open"); // Linux XDG standard
 #endif
 String studio::App::sequence_separator(".");
+bool studio::App::navigator_uses_cairo=false;
+bool studio::App::workarea_uses_cairo=false;
 
 static int max_recent_files_=25;
 int studio::App::get_max_recent_files() { return max_recent_files_; }
@@ -415,7 +418,7 @@ public:
 	virtual bool
 	task(const std::string &task)
 	{
-		std::cerr<<task<<std::endl;
+		std::cerr<<task.c_str()<<std::endl;
 		while(studio::App::events_pending())studio::App::iteration(false);
 		return true;
 	}
@@ -432,7 +435,7 @@ public:
 	virtual bool
 	warning(const std::string &err)
 	{
-		std::cerr<<"warning: "<<err<<std::endl;
+		std::cerr<<"warning: "<<err.c_str()<<std::endl;
 		while(studio::App::events_pending())studio::App::iteration(false);
 		return true;
 	}
@@ -594,6 +597,16 @@ public:
 				value=App::sequence_separator;
 				return true;
 			}
+			if(key=="navigator_uses_cairo")
+			{
+				value=strprintf("%i",(int)App::navigator_uses_cairo);
+				return true;
+			}
+			if(key=="workarea_uses_cairo")
+			{
+				value=strprintf("%i",(int)App::workarea_uses_cairo);
+				return true;
+			}
 		}
 		catch(...)
 		{
@@ -712,6 +725,19 @@ public:
 			if(key=="sequence_separator")
 			{
 				App::sequence_separator=value;
+				return true;
+			}
+			if(key=="navigator_uses_cairo")
+			{
+				int i(atoi(value.c_str()));
+				App::navigator_uses_cairo=i;
+				return true;
+			}
+			if(key=="workarea_uses_cairo")
+			{
+				int i(atoi(value.c_str()));
+				App::workarea_uses_cairo=i;
+				return true;
 			}
 		}
 		catch(...)
@@ -743,6 +769,8 @@ public:
 		ret.push_back("preferred_fps");
 		ret.push_back("predefined_fps");
 		ret.push_back("sequence_separator");
+		ret.push_back("navigator_uses_cairo");
+		ret.push_back("workarea_uses_cairo");
 		return ret;
 	}
 };
@@ -763,14 +791,15 @@ init_ui_manager()
 	menus_action_group->add( Gtk::Action::create("menu-view", _("_View")) );
 	menus_action_group->add( Gtk::Action::create("menu-canvas", _("_Canvas")) );
 	menus_action_group->add( Gtk::Action::create("menu-layer", _("_Layer")) );
-	menus_action_group->add( Gtk::Action::create("menu-duck-mask", _("Show/Hide Ducks")) );
+	menus_action_group->add( Gtk::Action::create("menu-duck-mask", _("Show/Hide Handles")) );
 	menus_action_group->add( Gtk::Action::create("menu-preview-quality", _("Preview Quality")) );
 	menus_action_group->add( Gtk::Action::create("menu-lowres-pixel", _("Low-Res Pixel Size")) );
 	menus_action_group->add( Gtk::Action::create("menu-layer-new", _("New Layer")) );
 	menus_action_group->add( Gtk::Action::create("menu-keyframe", _("Keyframe")) );
-	menus_action_group->add( Gtk::Action::create("menu-group", _("Group")) );
+	menus_action_group->add( Gtk::Action::create("menu-group", _("Set")) );
 	menus_action_group->add( Gtk::Action::create("menu-state", _("Tool")) );
 	menus_action_group->add( Gtk::Action::create("menu-toolbox", _("Toolbox")) );
+	menus_action_group->add( Gtk::Action::create("menu-plugins", _("Plug-Ins")) );
 
 	// Add the synfigapp actions...
 	synfigapp::Action::Book::iterator iter;
@@ -814,19 +843,19 @@ init_ui_manager()
 	DEFINE_ACTION("cut", Gtk::StockID("gtk-cut"));
 	DEFINE_ACTION("copy", Gtk::StockID("gtk-copy"));
 	DEFINE_ACTION("paste", Gtk::StockID("gtk-paste"));
-	DEFINE_ACTION("select-all-ducks", _("Select All Ducks"));
-	DEFINE_ACTION("unselect-all-ducks", _("Unselect All Ducks"));
+	DEFINE_ACTION("select-all-ducks", _("Select All Handles"));
+	DEFINE_ACTION("unselect-all-ducks", _("Unselect All Handles"));
 	DEFINE_ACTION("select-all-layers", _("Select All Layers"));
 	DEFINE_ACTION("unselect-all-layers", _("Unselect All Layers"));
 	DEFINE_ACTION("properties", _("Properties"));
 
-	DEFINE_ACTION("mask-position-ducks", _("Show Position Ducks"));
-	DEFINE_ACTION("mask-vertex-ducks", _("Show Vertex Ducks"));
-	DEFINE_ACTION("mask-tangent-ducks", _("Show Tangent Ducks"));
-	DEFINE_ACTION("mask-radius-ducks", _("Show Radius Ducks"));
-	DEFINE_ACTION("mask-width-ducks", _("Show Width Ducks"));
-	DEFINE_ACTION("mask-angle-ducks", _("Show Angle Ducks"));
-	DEFINE_ACTION("mask-widthpoint-position-ducks", _("Show WidthPoints Position Ducks"));
+	DEFINE_ACTION("mask-position-ducks", _("Show Position Handles"));
+	DEFINE_ACTION("mask-vertex-ducks", _("Show Vertex Handles"));
+	DEFINE_ACTION("mask-tangent-ducks", _("Show Tangent Handles"));
+	DEFINE_ACTION("mask-radius-ducks", _("Show Radius Handles"));
+	DEFINE_ACTION("mask-width-ducks", _("Show Width Handles"));
+	DEFINE_ACTION("mask-angle-ducks", _("Show Angle Handles"));
+	DEFINE_ACTION("mask-widthpoint-position-ducks", _("Show WidthPoints Position Handles"));
 	DEFINE_ACTION("quality-00", _("Use Parametric Renderer"));
 	DEFINE_ACTION("quality-01", _("Use Quality Level 1"));
 	DEFINE_ACTION("quality-02", _("Use Quality Level 2"));
@@ -866,16 +895,13 @@ init_ui_manager()
 	DEFINE_ACTION("seek-begin", _("Seek to Begin"));
 	DEFINE_ACTION("seek-end", _("Seek to End"));
 
-	DEFINE_ACTION("action-group_add", _("Add group"));
+	DEFINE_ACTION("action-group_add", _("Add set"));
 
 	DEFINE_ACTION("canvas-new", _("New Canvas"));
 
 	DEFINE_ACTION("amount-inc", _("Increase Amount"));
 	DEFINE_ACTION("amount-dec", _("Decrease Amount"));
 
-#undef DEFINE_ACTION
-#undef DEFINE_ACTION_2
-#undef DEFINE_ACTION_SIG
 
     Glib::ustring ui_info =
 "<ui>"
@@ -1006,10 +1032,31 @@ init_ui_manager()
 "	<menu action='menu-keyframe'>"
 "		<menuitem action='keyframe-properties'/>"
 "	</menu>"
+"	<menu action='menu-plugins'>"
+;
+
+	list<synfigapp::PluginManager::plugin> plugin_list = studio::App::plugin_manager.get_list();
+	for(list<synfigapp::PluginManager::plugin>::const_iterator p=plugin_list.begin();p!=plugin_list.end();++p) {
+
+		// TODO: (Plugins) Arrange menu items into groups
+
+		synfigapp::PluginManager::plugin plugin = *p;
+		
+		DEFINE_ACTION(plugin.id, plugin.name);
+		ui_info += strprintf("		<menuitem action='%s'/>", plugin.id.c_str());
+	}
+
+	ui_info +=
+"	</menu>"
 "	</popup>"
 
 "</ui>"
 ;
+
+	#undef DEFINE_ACTION
+	#undef DEFINE_ACTION_2
+	#undef DEFINE_ACTION_SIG
+
 /*		"<ui>"
         "  <menubar name='MenuBar'>"
         "    <menu action='MenuFile'>"
@@ -1162,14 +1209,14 @@ App::App(int *argc, char ***argv):
 
 	distance_system=Distance::SYSTEM_UNITS;
 
-	if(mkdir(get_user_app_directory().c_str(),ACCESSPERMS)<0)
+	if(mkdir(synfigapp::Main::get_user_app_directory().c_str(),ACCESSPERMS)<0)
 	{
 		if(errno!=EEXIST)
-			synfig::error("UNABLE TO CREATE \"%s\"",get_user_app_directory().c_str());
+			synfig::error("UNABLE TO CREATE \"%s\"",synfigapp::Main::get_user_app_directory().c_str());
 	}
 	else
 	{
-		synfig::info("Created directory \"%s\"",get_user_app_directory().c_str());
+		synfig::info("Created directory \"%s\"",synfigapp::Main::get_user_app_directory().c_str());
 	}
 
 
@@ -1214,6 +1261,31 @@ App::App(int *argc, char ***argv):
 
 	try
 	{
+		studio_init_cb.task(_("Loading Plugins..."));
+		
+		std::string pluginsprefix;
+	
+		// system plugins path
+#ifdef WIN32
+		pluginsprefix=App::get_base_path()+ETL_DIRECTORY_SEPARATOR+PLUGIN_DIR;
+#else
+		pluginsprefix=PLUGIN_DIR;
+#endif
+		char* synfig_root=getenv("SYNFIG_ROOT");
+		if(synfig_root) {
+			pluginsprefix=std::string(synfig_root)
+				+ETL_DIRECTORY_SEPARATOR+"share"
+				+ETL_DIRECTORY_SEPARATOR+"synfig"
+				+ETL_DIRECTORY_SEPARATOR+"plugins";
+		}
+		plugin_manager.load_dir(pluginsprefix);
+		
+		// user plugins path
+		pluginsprefix=Glib::build_filename(synfigapp::Main::get_user_app_directory(),"plugins");
+		plugin_manager.load_dir(pluginsprefix);
+		
+		
+		
 		studio_init_cb.task(_("Init UI Manager..."));
 		App::ui_manager_=studio::UIManager::create();
 		init_ui_manager();
@@ -1250,7 +1322,7 @@ App::App(int *argc, char ***argv):
 		dock_layers=new studio::Dock_Layers();
 		dock_manager->register_dockable(*dock_layers);
 
-		studio_init_cb.task(_("Init Params..."));
+		studio_init_cb.task(_("Init Parameters..."));
 		dock_params=new studio::Dock_Params();
 		dock_manager->register_dockable(*dock_params);
 
@@ -1258,7 +1330,7 @@ App::App(int *argc, char ***argv):
 		dock_meta_data=new studio::Dock_MetaData();
 		dock_manager->register_dockable(*dock_meta_data);
 
-		studio_init_cb.task(_("Init Children..."));
+		studio_init_cb.task(_("Init Library..."));
 		dock_children=new studio::Dock_Children();
 		dock_manager->register_dockable(*dock_children);
 
@@ -1278,7 +1350,7 @@ App::App(int *argc, char ***argv):
 		dock_curves = new studio::Dock_Curves();
 		dock_manager->register_dockable(*dock_curves);
 
-		studio_init_cb.task(_("Init Layer Groups..."));
+		studio_init_cb.task(_("Init Layer Sets..."));
 		dock_layer_groups = new studio::Dock_LayerGroups();
 		dock_manager->register_dockable(*dock_layer_groups);
 
@@ -1305,8 +1377,8 @@ App::App(int *argc, char ***argv):
 		state_manager->add_state(&state_circle);
 		state_manager->add_state(&state_rectangle);
 		state_manager->add_state(&state_star);
-		state_manager->add_state(&state_gradient);
 		if(!getenv("SYNFIG_DISABLE_POLYGON")) state_manager->add_state(&state_polygon); // Enabled - for working without ducks
+		state_manager->add_state(&state_gradient);
 
 		/* bline tools */
 		state_manager->add_state(&state_bline);
@@ -1460,21 +1532,10 @@ App::~App()
 	instance_list.clear();
 }
 
-String
-App::get_user_app_directory()
-{
-//! \todo do we need locale_from_utf8() on non-Windows boxes too?  (bug #1837445)
-#ifdef WIN32
-	return Glib::locale_from_utf8(Glib::build_filename(Glib::get_home_dir(),SYNFIG_USER_APP_DIR));
-#else
-	return Glib::build_filename(Glib::get_home_dir(),SYNFIG_USER_APP_DIR);
-#endif
-}
-
 synfig::String
 App::get_config_file(const synfig::String& file)
 {
-	return Glib::build_filename(get_user_app_directory(),file);
+	return Glib::build_filename(synfigapp::Main::get_user_app_directory(),file);
 }
 
 //! set the \a instance's canvas(es) position and size to be those specified in the first entry of recent_files_window_size
@@ -1658,7 +1719,7 @@ App::save_settings()
 			list<string>::reverse_iterator iter;
 
 			for(iter=recent_files.rbegin();iter!=recent_files.rend();iter++)
-				file<<*iter<<endl;
+				file<<(*iter).c_str()<<endl;
 		}while(0);
 		do{
 			std::string filename=get_config_file("recentfiles")+std::string("_window_size");
@@ -1674,7 +1735,7 @@ App::save_settings()
 			list<string>::reverse_iterator iter;
 
 			for(iter=recent_files_window_size.rbegin();iter!=recent_files_window_size.rend();iter++)
-				file<<*iter<<endl;
+				file<<(*iter).c_str()<<endl;
 
 		}while(0);
 		std::string filename=get_config_file("settings");
@@ -1861,6 +1922,8 @@ App::reset_initial_preferences()
 	synfigapp::Main::settings().set_value("pref.preferred_fps","24.0");
 	synfigapp::Main::settings().set_value("pref.predefined_fps",DEFAULT_PREDEFINED_FPS);
 	synfigapp::Main::settings().set_value("sequence_separator", ".");
+	synfigapp::Main::settings().set_value("navigator_uses_cairo", "0");
+	synfigapp::Main::settings().set_value("workarea_uses_cairo", "0");
 }
 
 bool
@@ -1876,7 +1939,6 @@ App::quit()
 {
 	if(shutdown_in_progress)return;
 
-
 	get_ui_interface()->task(_("Quit Request"));
 	if(Busy::count)
 	{
@@ -1939,8 +2001,6 @@ App::quit()
 		//(*iter)->close();
 	}
 
-	shutdown_in_progress=true;
-
 	instance_list.clear();
 
 	while(studio::App::events_pending())studio::App::iteration(false);
@@ -2120,7 +2180,8 @@ App::dialog_save_file(const std::string &title, std::string &filename, std::stri
 	{
 		file_type_enum = manage(new Widget_Enum());
 		file_type_enum->set_param_desc(ParamDesc().set_hint("enum")
-				.add_enum_value(synfig::RELEASE_VERSION_0_63_05, "0.63.05", strprintf("0.63.05 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_63_05, "0.64.0", strprintf("0.64.0 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.05", "0.63.05")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.04", "0.63.04")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_03, "0.63.03", "0.63.03")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_02, "0.63.02", "0.63.02")
@@ -2578,7 +2639,7 @@ App::set_selected_canvas_view(etl::loose_handle<CanvasView> canvas_view)
 	if(canvas_view)
 	{
 		selected_instance=canvas_view->get_instance();
-		signal_instance_selected()(canvas_view->get_instance());
+		signal_instance_selected()(selected_instance);
 	}
 /*
 	if(get_selected_canvas_view()==canvas_view)
