@@ -39,6 +39,7 @@
 #include "app.h"
 #include <synfig/savecanvas.h>
 #include <synfig/loadcanvas.h>
+#include <synfigapp/main.h>
 #include <fstream>
 #include <iostream>
 #include "instance.h"
@@ -109,7 +110,7 @@ AutoRecover::~AutoRecover()
 synfig::String
 AutoRecover::get_shadow_directory()
 {
-	return Glib::build_filename(App::get_user_app_directory(),"tmp");
+	return Glib::build_filename(synfigapp::Main::get_user_app_directory(),"tmp");
 }
 
 int
@@ -219,7 +220,7 @@ AutoRecover::auto_backup()
 					continue;
 
 				Canvas::Handle canvas((*iter)->get_canvas());
-				file<<canvas->get_file_name()<<endl;
+				file<<canvas->get_file_name().c_str()<<endl;
 				save_canvas(get_shadow_file_name(canvas->get_file_name()),canvas);
 				savecount++;
 			}
