@@ -7,7 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**	Copyright (c) 2008, 2009 Carlos López
+**	Copyright (c) 2008, 2009, 2012 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -82,7 +82,7 @@ Dialog_Setup::Dialog_Setup():
 #ifdef SINGLE_THREADED
 	toggle_single_threaded(_("Use Only a Single Thread")),
 #endif
-	toggle_restrict_radius_ducks(_("Restrict Real-Valued Ducks to Top Right Quadrant")),
+	toggle_restrict_radius_ducks(_("Restrict Real-Valued Handles to Top Right Quadrant")),
 	toggle_resize_imported_images(_("Scale New Imported Images to Fit Canvas")),
 	adj_pref_x_size(480,1,10000,1,10,0),
 	adj_pref_y_size(270,1,10000,1,10,0),
@@ -298,6 +298,12 @@ Dialog_Setup::Dialog_Setup():
 	// Render - Image sequence separator
 	attach_label(render_table, _("Image Sequence Separator String"), 0, xpadding, ypadding);
 	render_table->attach(image_sequence_separator, 1, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	// Render - Use Cairo on Navigator
+	attach_label(render_table, _("Use Cairo render on Navigator"), 1, xpadding, ypadding);
+	render_table->attach(toggle_navigator_uses_cairo, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	// Render - Use Cairo on WorkArea
+	attach_label(render_table, _("Use Cairo render on WorkArea"), 2, xpadding, ypadding);
+	render_table->attach(toggle_workarea_uses_cairo, 1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 	show_all_children();
 }
@@ -366,6 +372,12 @@ Dialog_Setup::on_apply_pressed()
 	// Set the preferred image sequence separator
 	App::sequence_separator=image_sequence_separator.get_text();
 
+	// Set the navigator uses cairo flag
+	App::navigator_uses_cairo=toggle_navigator_uses_cairo.get_active();
+
+	// Set the workarea uses cairo flag
+	App::workarea_uses_cairo=toggle_workarea_uses_cairo.get_active();
+
 	App::save_settings();
 
 	App::setup_changed();
@@ -516,6 +528,12 @@ Dialog_Setup::refresh()
 
 	//Refresh the sequence separator
 	image_sequence_separator.set_text(App::sequence_separator);
+
+	// Refresh the status of the navigator_uses_cairo flag
+	toggle_navigator_uses_cairo.set_active(App::navigator_uses_cairo);
+
+	// Refresh the status of the workarea_uses_cairo flag
+	toggle_workarea_uses_cairo.set_active(App::workarea_uses_cairo);
 }
 
 GammaPattern::GammaPattern():
