@@ -351,11 +351,11 @@ StatePolygon_Context::StatePolygon_Context(CanvasView* canvas_view):
 	entry_id(),
 	checkbutton_invert(_("Invert")),
 	checkbutton_layer_polygon(_("Create Polygon Layer")),
-	checkbutton_layer_region(_("Create Region BLine")),
-	checkbutton_layer_outline(_("Create Outline BLine")),
-	checkbutton_layer_advanced_outline(_("Create Advanced Outline BLine")),
-	checkbutton_layer_curve_gradient(_("Create Curve Gradient BLine")),
-	checkbutton_layer_plant(_("Create Plant BLine")),
+	checkbutton_layer_region(_("Create Region")),
+	checkbutton_layer_outline(_("Create Outline")),
+	checkbutton_layer_advanced_outline(_("Create Advanced Outline")),
+	checkbutton_layer_curve_gradient(_("Create Curve Gradient")),
+	checkbutton_layer_plant(_("Create Plant")),
 	checkbutton_layer_link_origins(_("Link Origins")),
 	button_make(_("Make")),
 	adj_feather(0,0,10000,0.01,0.1),
