@@ -2,7 +2,7 @@
 /*!	\file waypointadd.cpp
 **	\brief Template File
 **
-**	$Id: waypointadd.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -47,13 +47,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::WaypointAdd);
-ACTION_SET_NAME(Action::WaypointAdd,"waypoint_add");
+ACTION_SET_NAME(Action::WaypointAdd,"WaypointAdd");
 ACTION_SET_LOCAL_NAME(Action::WaypointAdd,N_("Add Waypoint"));
 ACTION_SET_TASK(Action::WaypointAdd,"add");
 ACTION_SET_CATEGORY(Action::WaypointAdd,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::WaypointAdd,0);
 ACTION_SET_VERSION(Action::WaypointAdd,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointAdd,"$Id: waypointadd.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::WaypointAdd,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
