@@ -199,7 +199,7 @@ Settings::save_to_file(const synfig::String& filename)const
 			{
 				if(!file)return false;
 				String ret = get_value(*iter);
-				if (ret != String()) file<<*iter<<'='<<(ret == "none" ? "normal" : ret)<<endl;
+				if (ret != String()) file<<(*iter).c_str()<<'='<<(ret == "none" ? "normal" : ret).c_str()<<endl;
 			}
 		}
 
